@@ -133,6 +133,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_kms
@@ -155,19 +157,19 @@ class S3ToSqs(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        s3_event_filters: typing.Optional[typing.Sequence[aws_cdk.aws_s3.NotificationKeyFilter]] = None,
+        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        s3_event_filters: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.NotificationKeyFilter, typing.Dict[str, typing.Any]]]] = None,
         s3_event_types: typing.Optional[typing.Sequence[aws_cdk.aws_s3.EventType]] = None,
     ) -> None:
         '''
@@ -192,6 +194,10 @@ class S3ToSqs(
         :since: 0.8.0
         :summary: Constructs a new instance of the S3ToSqs class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(S3ToSqs.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = S3ToSqsProps(
             bucket_props=bucket_props,
             dead_letter_queue_props=dead_letter_queue_props,
@@ -266,19 +272,19 @@ class S3ToSqsProps:
     def __init__(
         self,
         *,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        s3_event_filters: typing.Optional[typing.Sequence[aws_cdk.aws_s3.NotificationKeyFilter]] = None,
+        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        s3_event_filters: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.NotificationKeyFilter, typing.Dict[str, typing.Any]]]] = None,
         s3_event_types: typing.Optional[typing.Sequence[aws_cdk.aws_s3.EventType]] = None,
     ) -> None:
         '''
@@ -309,6 +315,22 @@ class S3ToSqsProps:
             logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(S3ToSqsProps.__init__)
+            check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
+            check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
+            check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
+            check_type(argname="argument enable_encryption_with_customer_managed_key", value=enable_encryption_with_customer_managed_key, expected_type=type_hints["enable_encryption_with_customer_managed_key"])
+            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
+            check_type(argname="argument encryption_key_props", value=encryption_key_props, expected_type=type_hints["encryption_key_props"])
+            check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
+            check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
+            check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
+            check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
+            check_type(argname="argument max_receive_count", value=max_receive_count, expected_type=type_hints["max_receive_count"])
+            check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
+            check_type(argname="argument s3_event_filters", value=s3_event_filters, expected_type=type_hints["s3_event_filters"])
+            check_type(argname="argument s3_event_types", value=s3_event_types, expected_type=type_hints["s3_event_types"])
         self._values: typing.Dict[str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
